use axum::{
    extract::Path,
    response::{IntoResponse, Response},
};
use log::debug;
use serde::Serialize;

use crate::USER;

#[derive(Serialize)]
pub struct UsersResponse {
    #[serde(rename = "@context")]
    context: String,
    r#type: String,
    name: String,
    id: String,
}

pub async fn users_get(Path(user): Path<String>) -> UsersResponse {
    debug!("Got request for actor: {user}");
    assert_eq!(user, USER);

    UsersResponse {
        context: "https://www.w3.org/ns/activitystreams".to_string(),
        r#type: "Person".to_string(),
        name: "Sally Smith".to_string(),
        id: "https://testhost.com/users/test".to_string(),
    }
}

impl IntoResponse for UsersResponse {
    fn into_response(self) -> Response {
        Response::builder()
            .header("content-type", "application/activity+json; charset=utf-8")
            .body(serde_json::to_string(&self).unwrap().into())
            .unwrap()
    }
}
