use log::debug;
use webfinger_rs::{Link, Rel, WebFingerRequest, WebFingerResponse};

use crate::{HOST, USER};

pub async fn webfinger_get(request: WebFingerRequest) -> WebFingerResponse {
    let resource = request.resource.to_string();
    debug!("Got webfinger request for resource: {resource}");
    let Some((typ, val)) = resource.split_once(':') else {
        panic!()
    };
    assert_eq!(typ, "acct");
    let Some((usr, dom)) = val.split_once('@') else {
        panic!()
    };
    assert_eq!(usr, USER);
    assert_eq!(dom, HOST);

    WebFingerResponse::builder(format!("acct:{USER}@{HOST}"))
        .alias(format!("https://{HOST}/users/{USER}"))
        .link(
            Link::builder(Rel::new("self"))
                .r#type("application/activity+json")
                .href(format!("https://{HOST}/users/{USER}")),
        )
        .build()
}
